@@ -1,45 +1,15 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
-#include "globals.h"
+
+#include "dht/dht_server.h"
 
 #include <algorithm>
 #include <cstdio>
 
+#include "manager.h"
+#include "thread_main.h"
+#include "dht/dht_bucket.h"
+#include "dht/dht_router.h"
+#include "dht/dht_transaction.h"
 #include "torrent/exceptions.h"
 #include "torrent/connection_manager.h"
 #include "torrent/download_info.h"
@@ -51,24 +21,11 @@
 #include "torrent/utils/log.h"
 #include "tracker/tracker_dht.h"
 
-#include "dht_bucket.h"
-#include "dht_router.h"
-#include "dht_transaction.h"
-
-#include "manager.h"
-
 #define LT_LOG_THIS(log_fmt, ...)                                       \
   lt_log_print_subsystem(torrent::LOG_DHT_SERVER, "dht_server", log_fmt, __VA_ARGS__);
 
 namespace torrent {
 
-const char* DhtServer::queries[] = {
-  "ping",
-  "find_node",
-  "get_peers",
-  "announce_peer",
-};
-
 // List of all possible keys we need/support in a DHT message.
 // Unsupported keys we receive are dropped (ignored) while decoding.
 // See torrent/object_static_map.h for how this works.
@@ -109,15 +66,9 @@ private:
 };
 
 DhtServer::DhtServer(DhtRouter* router) :
-  m_router(router),
-
-  m_uploadNode(60),
-  m_downloadNode(60),
-
-  m_uploadThrottle(manager->upload_throttle()->throttle_list()),
-  m_downloadThrottle(manager->download_throttle()->throttle_list()),
-
-  m_networkUp(false) {
+    m_router(router),
+    m_uploadThrottle(manager->upload_throttle()->throttle_list()),
+    m_downloadThrottle(manager->download_throttle()->throttle_list()) {
 
   get_fd().clear();
   reset_statistics();
@@ -126,6 +77,8 @@ DhtServer::DhtServer(DhtRouter* router) :
   // actually open it until the server is started, which may not
   // happen until the first non-private torrent is started.
   manager->connection_manager()->inc_socket_count();
+
+  m_task_timeout.slot() = [this] { receive_timeout(); };
 }
 
 DhtServer::~DhtServer() {
@@ -169,17 +122,15 @@ DhtServer::start(int port) {
     throw;
   }
 
-  m_taskTimeout.slot() = std::bind(&DhtServer::receive_timeout, this);
-
   m_uploadNode.set_list_iterator(m_uploadThrottle->end());
-  m_uploadNode.slot_activate() = std::bind(&SocketBase::receive_throttle_up_activate, static_cast<SocketBase*>(this));
+  m_uploadNode.slot_activate() = [this] { receive_throttle_up_activate(); };
 
   m_downloadNode.set_list_iterator(m_downloadThrottle->end());
   m_downloadThrottle->insert(&m_downloadNode);
 
-  manager->poll()->open(this);
-  manager->poll()->insert_read(this);
-  manager->poll()->insert_error(this);
+  this_thread::poll()->open(this);
+  this_thread::poll()->insert_read(this);
+  this_thread::poll()->insert_error(this);
 }
 
 void
@@ -191,15 +142,12 @@ DhtServer::stop() {
 
   clear_transactions();
 
-  priority_queue_erase(&taskScheduler, &m_taskTimeout);
+  this_thread::scheduler()->erase(&m_task_timeout);
 
   m_uploadThrottle->erase(&m_uploadNode);
   m_downloadThrottle->erase(&m_downloadNode);
 
-  manager->poll()->remove_read(this);
-  manager->poll()->remove_write(this);
-  manager->poll()->remove_error(this);
-  manager->poll()->close(this);
+  this_thread::poll()->remove_and_close(this);
 
   get_fd().close();
   get_fd().clear();
@@ -223,7 +171,7 @@ DhtServer::reset_statistics() {
 void
 DhtServer::ping(const HashString& id, const rak::socket_address* sa) {
   // No point pinging a node that we're already contacting otherwise.
-  transaction_itr itr = m_transactions.lower_bound(DhtTransaction::key(sa, 0));
+  auto itr = m_transactions.lower_bound(DhtTransaction::key(sa, 0));
   if (itr == m_transactions.end() || !DhtTransaction::key_match(itr->first, sa))
     add_transaction(new DhtTransactionPing(id, sa), packet_prio_low);
 }
@@ -231,11 +179,13 @@ DhtServer::ping(const HashString& id, const rak::socket_address* sa) {
 // Contact nodes in given bucket and ask for their nodes closest to target.
 void
 DhtServer::find_node(const DhtBucket& contacts, const HashString& target) {
-  DhtSearch* search = new DhtSearch(target, contacts);
+  auto search = new DhtSearch(target, contacts);
 
-  DhtSearch::const_accessor n;
-  while ((n = search->get_contact()) != search->end())
+  auto n = search->get_contact();
+  while (n != search->end()) {
     add_transaction(new DhtTransactionFindNode(n), packet_prio_low);
+    n = search->get_contact();
+  }
 
   // This shouldn't happen, it means we had no contactable nodes at all.
   if (!search->start())
@@ -244,11 +194,13 @@ DhtServer::find_node(const DhtBucket& contacts, const HashString& target) {
 
 void
 DhtServer::announce(const DhtBucket& contacts, const HashString& infoHash, TrackerDht* tracker) {
-  DhtAnnounce* announce = new DhtAnnounce(infoHash, tracker, contacts);
+  auto announce = new DhtAnnounce(infoHash, tracker, contacts);
+  auto n        = announce->get_contact();
 
-  DhtSearch::const_accessor n;
-  while ((n = announce->get_contact()) != announce->end())
+  while (n != announce->end()) {
     add_transaction(new DhtTransactionFindNode(n), packet_prio_high);
+    n = announce->get_contact();
+  }
 
   // This can only happen if all nodes we know are bad.
   if (!announce->start())
@@ -258,14 +210,14 @@ DhtServer::announce(const DhtBucket& contacts, const HashString& infoHash, Track
 }
 
 void
-DhtServer::cancel_announce(DownloadInfo* info, const TrackerDht* tracker) {
-  transaction_itr itr = m_transactions.begin();
+DhtServer::cancel_announce(const HashString* info_hash, const TrackerDht* tracker) {
+  auto itr = m_transactions.begin();
 
   while (itr != m_transactions.end()) {
     if (itr->second->is_search() && itr->second->as_search()->search()->is_announce()) {
-      DhtAnnounce* announce = static_cast<DhtAnnounce*>(itr->second->as_search()->search());
+      auto announce = static_cast<DhtAnnounce*>(itr->second->as_search()->search());
 
-      if ((info == NULL || announce->target() == info->hash()) && (tracker == NULL || announce->tracker() == tracker)) {
+      if ((info_hash == nullptr || announce->target() == *info_hash) && (tracker == nullptr || announce->tracker() == tracker)) {
         drop_packet(itr->second->packet());
         delete itr->second;
         m_transactions.erase(itr++);
@@ -353,7 +305,7 @@ DhtServer::create_get_peers_response(const DhtMessage& req, const rak::socket_ad
 }
 
 void
-DhtServer::create_announce_peer_response(const DhtMessage& req, const rak::socket_address* sa, DhtMessage& reply) {
+DhtServer::create_announce_peer_response(const DhtMessage& req, const rak::socket_address* sa, [[maybe_unused]] DhtMessage& reply) {
   raw_string info_hash = req[key_a_infoHash].as_raw_string();
 
   if (info_hash.size() < HashString::size_data)
@@ -368,8 +320,8 @@ DhtServer::create_announce_peer_response(const DhtMessage& req, const rak::socke
 
 void
 DhtServer::process_response(const HashString& id, const rak::socket_address* sa, const DhtMessage& response) {
-  int transactionId = (unsigned char)response[key_t].as_raw_string().data()[0];
-  transaction_itr itr = m_transactions.find(DhtTransaction::key(sa, transactionId));
+  int  transactionId = static_cast<unsigned char>(response[key_t].as_raw_string().data()[0]);
+  auto itr = m_transactions.find(DhtTransaction::key(sa, transactionId));
 
   // Response to a transaction we don't have in our table. At this point it's
   // impossible to tell whether it used to be a valid transaction but timed out
@@ -428,8 +380,8 @@ DhtServer::process_response(const HashString& id, const rak::socket_address* sa,
 
 void
 DhtServer::process_error(const rak::socket_address* sa, const DhtMessage& error) {
-  int transactionId = (unsigned char)error[key_t].as_raw_string().data()[0];
-  transaction_itr itr = m_transactions.find(DhtTransaction::key(sa, transactionId));
+  int  transactionId = static_cast<unsigned char>(error[key_t].as_raw_string().data()[0]);
+  auto itr = m_transactions.find(DhtTransaction::key(sa, transactionId));
 
   if (itr == m_transactions.end())
     return;
@@ -459,10 +411,10 @@ DhtServer::parse_find_node_reply(DhtTransactionSearch* transaction, raw_string n
             reinterpret_cast<const compact_node_info*>(nodes.data() + nodes.size() - nodes.size() % sizeof(compact_node_info)),
             std::back_inserter(list));
 
-  for (node_info_list::iterator itr = list.begin(); itr != list.end(); ++itr) {
-    if (itr->id() != m_router->id()) {
-      rak::socket_address sa = itr->address();
-      transaction->search()->add_contact(itr->id(), &sa);
+  for (auto& node : list) {
+    if (node.id() != m_router->id()) {
+      rak::socket_address sa = node.address();
+      transaction->search()->add_contact(node.id(), &sa);
     }
   }
 
@@ -471,7 +423,7 @@ DhtServer::parse_find_node_reply(DhtTransactionSearch* transaction, raw_string n
 
 void
 DhtServer::parse_get_peers_reply(DhtTransactionGetPeers* transaction, const DhtMessage& response) {
-  DhtAnnounce* announce = static_cast<DhtAnnounce*>(transaction->as_search()->search());
+  auto announce = static_cast<DhtAnnounce*>(transaction->as_search()->search());
 
   transaction->complete(true);
 
@@ -494,14 +446,16 @@ DhtServer::find_node_next(DhtTransactionSearch* transaction) {
   if (transaction->search()->is_announce())
     priority = packet_prio_high;
 
-  DhtSearch::const_accessor node;
-  while ((node = transaction->search()->get_contact()) != transaction->search()->end())
+  auto node = transaction->search()->get_contact();
+  while (node != transaction->search()->end()) {
     add_transaction(new DhtTransactionFindNode(node), priority);
+    node = transaction->search()->get_contact();
+  }
 
   if (!transaction->search()->is_announce())
     return;
 
-  DhtAnnounce* announce = static_cast<DhtAnnounce*>(transaction->search());
+  auto announce = static_cast<DhtAnnounce*>(transaction->search());
   if (announce->complete()) {
     // We have found the 8 closest nodes to the info hash. Retrieve peers
     // from them and announce to them.
@@ -545,7 +499,7 @@ DhtServer::drop_packet(DhtTransactionPacket* packet) {
 }
 
 void
-DhtServer::create_query(transaction_itr itr, int tID, const rak::socket_address* sa, int priority) {
+DhtServer::create_query(transaction_itr itr, int tID, [[maybe_unused]] const rak::socket_address* sa, int priority) {
   if (itr->second->id() == m_router->id())
     throw internal_error("DhtServer::create_query trying to send to itself.");
 
@@ -583,7 +537,7 @@ DhtServer::create_query(transaction_itr itr, int tID, const rak::socket_address*
       break;
   }
 
-  DhtTransactionPacket* packet = new DhtTransactionPacket(transaction->address(), query, tID, transaction);
+  auto packet = new DhtTransactionPacket(transaction->address(), query, tID, transaction);
   transaction->set_packet(packet);
   add_packet(packet, priority);
 
@@ -626,15 +580,15 @@ DhtServer::add_transaction(DhtTransaction* transaction, int priority) {
   // unused one. Since normally only one or two transactions will be active per
   // node, a collision is extremely unlikely, and a linear search for the first
   // open one is the most efficient.
-  unsigned int rnd = (uint8_t)random();
+  unsigned int rnd = static_cast<uint8_t>(random());
   unsigned int id = rnd;
 
-  transaction_itr insertItr = m_transactions.lower_bound(transaction->key(rnd));
+  auto insertItr = m_transactions.lower_bound(transaction->key(rnd));
 
   // If key matches, keep trying successive IDs.
   while (insertItr != m_transactions.end() && insertItr->first == transaction->key(id)) {
     ++insertItr;
-    id = (uint8_t)(id + 1);
+    id = static_cast<uint8_t>(id + 1);
 
     // Give up after trying all possible IDs. This should never happen.
     if (id == rnd) {
@@ -705,9 +659,9 @@ DhtServer::failed_transaction(transaction_itr itr, bool quick) {
 
 void
 DhtServer::clear_transactions() {
-  for (transaction_map::iterator itr = m_transactions.begin(), last = m_transactions.end(); itr != last; itr++) {
-    drop_packet(itr->second->packet());
-    delete itr->second;
+  for (auto& transaction : m_transactions) {
+    drop_packet(transaction.second->packet());
+    delete transaction.second;
   }
 
   m_transactions.clear();
@@ -868,13 +822,13 @@ DhtServer::process_queue(packet_queue& queue, uint32_t* quota) {
       used += written;
       *quota -= written;
 
-      if ((unsigned int)written != packet->length())
+      if (static_cast<unsigned int>(written) != packet->length())
         throw network_error();
 
     } catch (network_error& e) {
       // Couldn't write packet, maybe something wrong with node address or routing, so mark node as bad.
       if (packet->has_transaction()) {
-        transaction_itr itr = m_transactions.find(transactionKey);
+        auto itr = m_transactions.find(transactionKey);
         if (itr == m_transactions.end())
           throw internal_error("DhtServer::process_queue could not find transaction.");
 
@@ -884,7 +838,7 @@ DhtServer::process_queue(packet_queue& queue, uint32_t* quota) {
 
     if (packet->has_transaction()) {
       // here transaction can be already deleted by failed_transaction.
-      transaction_itr itr = m_transactions.find(transactionKey);
+      auto itr = m_transactions.find(transactionKey);
       if (itr != m_transactions.end())
         packet->transaction()->set_packet(NULL);
     }
@@ -907,11 +861,11 @@ DhtServer::event_write() {
   uint32_t quota = m_uploadThrottle->node_quota(&m_uploadNode);
 
   if (quota == 0 || !process_queue(m_highQueue, &quota) || !process_queue(m_lowQueue, &quota)) {
-    manager->poll()->remove_write(this);
+    this_thread::poll()->remove_write(this);
     m_uploadThrottle->node_deactivate(&m_uploadNode);
 
   } else if (m_highQueue.empty() && m_lowQueue.empty()) {
-    manager->poll()->remove_write(this);
+    this_thread::poll()->remove_write(this);
     m_uploadThrottle->erase(&m_uploadNode);
   }
 }
@@ -924,21 +878,21 @@ void
 DhtServer::start_write() {
   if ((!m_highQueue.empty() || !m_lowQueue.empty()) && !m_uploadThrottle->is_throttled(&m_uploadNode)) {
     m_uploadThrottle->insert(&m_uploadNode);
-    manager->poll()->insert_write(this);
+    this_thread::poll()->insert_write(this);
   }
 
-  if (!m_taskTimeout.is_queued() && !m_transactions.empty())
-    priority_queue_insert(&taskScheduler, &m_taskTimeout, (cachedTime + rak::timer::from_seconds(5)).round_seconds());
+  if (!m_task_timeout.is_scheduled() && !m_transactions.empty())
+    this_thread::scheduler()->wait_for_ceil_seconds(&m_task_timeout, 5s);
 }
 
 void
 DhtServer::receive_timeout() {
-  transaction_itr itr = m_transactions.begin();
+  auto itr = m_transactions.begin();
   while (itr != m_transactions.end()) {
-    if (itr->second->has_quick_timeout() && itr->second->quick_timeout() < cachedTime.seconds()) {
+    if (itr->second->has_quick_timeout() && itr->second->quick_timeout() < this_thread::cached_seconds().count()) {
       itr = failed_transaction(itr, true);
 
-    } else if (itr->second->timeout() < cachedTime.seconds()) {
+    } else if (itr->second->timeout() < this_thread::cached_seconds().count()) {
       itr = failed_transaction(itr, false);
 
     } else {
