@@ -1,53 +1,17 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #ifndef LIBTORRENT_DHT_SERVER_H
 #define LIBTORRENT_DHT_SERVER_H
 
-#include <map>
+#include <array>
 #include <deque>
-#include <rak/priority_queue_default.h>
-#include <rak/socket_address.h>
+#include <map>
 
+#include "dht/dht_transaction.h"
 #include "net/socket_datagram.h"
 #include "net/throttle_node.h"
+#include "rak/socket_address.h"
 #include "torrent/hash_string.h"
 #include "torrent/object_raw_bencode.h"
-
-#include "dht_transaction.h"
+#include "torrent/utils/scheduler.h"
 
 namespace torrent {
 
@@ -64,9 +28,9 @@ class TrackerDht;
 class DhtServer : public SocketDatagram {
 public:
   DhtServer(DhtRouter* self);
-  ~DhtServer();
+  ~DhtServer() override;
 
-  const char*         type_name() const { return "dht"; }
+  const char*         type_name() const override         { return "dht"; }
 
   void                start(int port);
   void                stop();
@@ -90,7 +54,7 @@ public:
   void                announce(const DhtBucket& contacts, const HashString& infoHash, TrackerDht* tracker);
 
   // Cancel given announce for given tracker, or all matching announces if info/tracker NULL.
-  void                cancel_announce(DownloadInfo* info, const TrackerDht* tracker);
+  void                cancel_announce(const HashString* info_hash, const TrackerDht* tracker);
 
   // Called every 15 minutes.
   void                update();
@@ -103,39 +67,44 @@ public:
   void                set_upload_throttle(ThrottleList* t)    { m_uploadThrottle = t; }
   void                set_download_throttle(ThrottleList* t)  { m_downloadThrottle = t; }
 
-  virtual void        event_read();
-  virtual void        event_write();
-  virtual void        event_error();
+  void                event_read() override;
+  void                event_write() override;
+  void                event_error() override;
 
 private:
   // DHT error codes.
-  static const int dht_error_generic    = 201;
-  static const int dht_error_server     = 202;
-  static const int dht_error_protocol   = 203;
-  static const int dht_error_bad_method = 204;
+  static constexpr int dht_error_generic    = 201;
+  static constexpr int dht_error_server     = 202;
+  static constexpr int dht_error_protocol   = 203;
+  static constexpr int dht_error_bad_method = 204;
 
-  struct compact_node_info {
+  struct [[gnu::packed]] compact_node_info {
     char                 _id[20];
     SocketAddressCompact _addr;
 
     HashString&          id()          { return *HashString::cast_from(_id); }
     rak::socket_address  address()     { return rak::socket_address(_addr); }
-  } __attribute__ ((packed));
+  };
 
-  typedef std::deque<DhtTransactionPacket*> packet_queue;
-  typedef std::list<compact_node_info> node_info_list;
+  using packet_queue   = std::deque<DhtTransactionPacket*>;
+  using node_info_list = std::list<compact_node_info>;
 
   // Pending transactions.
-  typedef std::map<DhtTransaction::key_type, DhtTransaction*> transaction_map;
-  typedef transaction_map::iterator transaction_itr;
+  using transaction_map = std::map<DhtTransaction::key_type, DhtTransaction*>;
+  using transaction_itr = transaction_map::iterator;
 
   // DHT transaction names for given transaction type.
-  static const char* queries[];
+  static constexpr std::array queries{
+    "ping",
+    "find_node",
+    "get_peers",
+    "announce_peer",
+  };
 
   // Priorities for the outgoing packets.
-  static const int packet_prio_high  = 2;  // For important queries we send (announces).
-  static const int packet_prio_low   = 1;  // For (relatively) unimportant queries we send.
-  static const int packet_prio_reply = 0;  // For replies to peer queries.
+  static constexpr int packet_prio_high  = 2;  // For important queries we send (announces).
+  static constexpr int packet_prio_low   = 1;  // For (relatively) unimportant queries we send.
+  static constexpr int packet_prio_reply = 0;  // For replies to peer queries.
 
   void                start_write();
 
@@ -168,26 +137,26 @@ private:
   bool                process_queue(packet_queue& queue, uint32_t* quota);
   void                receive_timeout();
 
-  DhtRouter*          m_router;
+  DhtRouter*          m_router{};
   packet_queue        m_highQueue;
   packet_queue        m_lowQueue;
   transaction_map     m_transactions;
 
-  rak::priority_item  m_taskTimeout;
+  utils::SchedulerEntry m_task_timeout;
 
-  ThrottleNode        m_uploadNode;
-  ThrottleNode        m_downloadNode;
+  ThrottleNode        m_uploadNode{60};
+  ThrottleNode        m_downloadNode{60};
 
-  ThrottleList*       m_uploadThrottle;
-  ThrottleList*       m_downloadThrottle;
+  ThrottleList*       m_uploadThrottle{};
+  ThrottleList*       m_downloadThrottle{};
 
-  unsigned int        m_queriesReceived;
-  unsigned int        m_queriesSent;
-  unsigned int        m_repliesReceived;
-  unsigned int        m_errorsReceived;
-  unsigned int        m_errorsCaught;
+  unsigned int        m_queriesReceived{};
+  unsigned int        m_queriesSent{};
+  unsigned int        m_repliesReceived{};
+  unsigned int        m_errorsReceived{};
+  unsigned int        m_errorsCaught{};
 
-  bool                m_networkUp;
+  bool                m_networkUp{false};
 };
 
 }
