@@ -4,11 +4,11 @@
 #include <functional>
 #include <inttypes.h>
 #include <string>
-#include <rak/unordered_vector.h>
-#include <rak/socket_address.h>
-#include <torrent/connection_manager.h>
 
 #include "net/socket_fd.h"
+#include "rak/socket_address.h"
+#include "rak/unordered_vector.h"
+#include "torrent/connection_manager.h"
 
 namespace torrent {
 
@@ -19,17 +19,17 @@ class PeerConnectionBase;
 
 class HandshakeManager : private rak::unordered_vector<Handshake*> {
 public:
-  typedef rak::unordered_vector<Handshake*> base_type;
-  typedef uint32_t                          size_type;
+  using base_type = rak::unordered_vector<Handshake*>;
+  using size_type = uint32_t;
 
-  typedef std::function<DownloadMain* (const char*)> slot_download;
+  using slot_download = std::function<DownloadMain*(const char*)>;
 
   // Do not connect to peers with this many or more failed chunks.
-  static const unsigned int max_failed = 3;
+  static constexpr unsigned int max_failed = 3;
 
   using base_type::empty;
 
-  HandshakeManager() { }
+  HandshakeManager() = default;
   ~HandshakeManager() { clear(); }
 
   size_type           size() const { return base_type::size(); }
@@ -59,6 +59,9 @@ public:
   ProtocolExtension*  default_extensions() const                        { return &DefaultExtensions; }
 
 private:
+  HandshakeManager(const HandshakeManager&) = delete;
+  HandshakeManager& operator=(const HandshakeManager&) = delete;
+
   void                create_outgoing(const rak::socket_address& sa, DownloadMain* info, int encryptionOptions);
   void                erase(Handshake* handshake);
 
