@@ -10,7 +10,6 @@
 
 #include "file.h"
 #include "file_manager.h"
-#include "globals.h"
 #include "manager.h"
 
 namespace torrent {
@@ -24,28 +23,17 @@ const int File::flag_previously_created;
 const int File::flag_prioritize_first;
 const int File::flag_prioritize_last;
 
-File::File() :
-  m_fd(-1),
-  m_protection(0),
-  m_flags(0),
-
-  m_offset(0),
-  m_size(0),
-  m_lastTouched(cachedTime.usec()),
-
-  m_completed(0),
-  m_priority(PRIORITY_NORMAL),
-
-  m_matchDepthPrev(0),
-  m_matchDepthNext(0) {
-}
+const int File::flag_attr_padding;
 
 File::~File() {
-  assert(!is_open() && "File::~File() called on an open file.");
+  assert((is_padding() || !is_open()) && "File::~File() called on an open file.");
 }
 
 bool
 File::is_created() const {
+  if (is_padding())
+    return true;
+
   rak::file_stat fs;
 
   // If we can't even get permission to do fstat, we might as well
@@ -62,20 +50,37 @@ File::is_created() const {
 
 bool
 File::is_correct_size() const {
+  if (is_padding())
+    return true;
+
   rak::file_stat fs;
 
   if (!fs.update(frozen_path()))
     return false;
 
-  return fs.is_regular() && (uint64_t)fs.size() == m_size;
+  return fs.is_regular() && static_cast<uint64_t>(fs.size()) == m_size;
+}
+
+void
+File::set_completed_chunks(uint32_t v) {
+  if (has_flags(flag_active))
+    throw internal_error("File::set_completed_chunks(...) called on an active file.");
+
+  if (v > size_chunks())
+    throw internal_error("File::set_completed_chunks(...) called with a value larger than the chunk size.");
+
+  m_completed = v;
 }
 
 // At some point we should pass flags for deciding if the correct size
 // is necessary, etc.
 
 bool
-File::prepare(int prot, int flags) {
-  m_lastTouched = cachedTime.usec();
+File::prepare(bool hashing, int prot, int flags) {
+  if (is_padding())
+    return true;
+
+  m_last_touched = this_thread::cached_time().count();
 
   // Check if we got write protection and flag_resize_queued is
   // set. If so don't quit as we need to try re-sizing, instead call
@@ -90,7 +95,7 @@ File::prepare(int prot, int flags) {
   else
     flags &= ~SocketFile::o_create;
 
-  if (!manager->file_manager()->open(this, prot, flags))
+  if (!manager->file_manager()->open(this, hashing, prot, flags))
     return false;
 
   m_flags |= flag_previously_created;
@@ -119,8 +124,8 @@ void
 File::set_match_depth(File* left, File* right) {
   uint32_t level = 0;
 
-  Path::const_iterator itrLeft = left->path()->begin();
-  Path::const_iterator itrRight = right->path()->begin();
+  auto itrLeft = left->path()->begin();
+  auto itrRight = right->path()->begin();
 
   while (itrLeft != left->path()->end() && itrRight != right->path()->end() && *itrLeft == *itrRight) {
     itrLeft++;
@@ -128,12 +133,15 @@ File::set_match_depth(File* left, File* right) {
     level++;
   }
 
-  left->m_matchDepthNext = level;
-  right->m_matchDepthPrev = level;
+  left->m_match_depth_next = level;
+  right->m_match_depth_prev = level;
 }
 
 bool
 File::resize_file() {
+  if (is_padding())
+    return true;
+
   if (!is_open())
     return false;
 
