@@ -37,6 +37,7 @@
 #include "config.h"
 
 #include <cstring>
+#include <set>
 
 #include "exceptions.h"
 #include "file.h"
@@ -56,28 +57,28 @@ file_split(FileList* fileList, FileList::iterator position, uint64_t maxSize, co
     throw input_error("Tried to split a file into more than 1000 parts.");
 
   // Also replace dwnlctor's vector.
-  FileList::split_type* splitList = new FileList::split_type[splitSize];
-  FileList::split_type* splitItr = splitList;
+  auto splitList = new FileList::split_type[splitSize];
+  auto splitItr = splitList;
 
-  unsigned int nameSize = srcPath->back().size() + suffix.size();
-  char         name[nameSize + 4];
-
-  std::memcpy(name, srcPath->back().c_str(), srcPath->back().size());
-  std::memcpy(name + srcPath->back().size(), suffix.c_str(), suffix.size());
+  const unsigned int nameSize = srcPath->back().size() + suffix.size();
+  std::string name;
+  name.reserve(nameSize + 4);
+  name += srcPath->back();
+  name += suffix;
 
   for (unsigned int i = 0; i != splitSize; ++i, ++splitItr) {
     if (i == splitSize - 1 && (*position)->size_bytes() % maxSize != 0)
-      splitItr->first = (*position)->size_bytes() % maxSize;
+      std::get<0>(*splitItr) = (*position)->size_bytes() % maxSize;
     else
-      splitItr->first = maxSize;
+      std::get<0>(*splitItr) = maxSize;
 
     name[nameSize + 0] = '0' + (i / 100) % 10;
     name[nameSize + 1] = '0' + (i / 10) % 10;
     name[nameSize + 2] = '0' + (i / 1) % 10;
     name[nameSize + 3] = '\0';
     
-    splitItr->second = *srcPath;
-    splitItr->second.back() = name;
+    std::get<1>(*splitItr) = *srcPath;
+    std::get<1>(*splitItr).back() = name;
   }
 
   return fileList->split(position, splitList, splitItr).second;
@@ -88,7 +89,7 @@ file_split_all(FileList* fileList, uint64_t maxSize, const std::string& suffix)
   if (maxSize == 0)
     throw input_error("Tried to split torrent files into zero sized chunks.");
 
-  FileList::iterator itr = fileList->begin();
+  auto itr = fileList->begin();
 
   while (itr != fileList->end())
     if ((*itr)->size_bytes() > maxSize && !(*itr)->path()->empty())
