@@ -5,9 +5,9 @@
 #include "helpers/test_thread.h"
 #include "helpers/test_utils.h"
 
-#include <torrent/exceptions.h>
-#include <torrent/utils/signal_bitfield.h>
-#include <torrent/utils/thread_base.h>
+#include "torrent/exceptions.h"
+#include "torrent/utils/signal_bitfield.h"
+#include "torrent/utils/thread.h"
 
 CPPUNIT_TEST_SUITE_NAMED_REGISTRATION(test_signal_bitfield, "torrent/utils");
 
@@ -21,13 +21,6 @@ check_index(std::atomic_uint32_t& bitfield, unsigned int index) {
   return bitfield & (1 << index);
 }
 
-void
-test_signal_bitfield::tearDown() {
-  CPPUNIT_ASSERT(torrent::thread_base::trylock_global_lock());
-  torrent::thread_base::release_global_lock();
-  test_fixture::tearDown();
-}
-
 static bool
 verify_did_internal_error(std::function<unsigned int ()> func, bool should_throw) {
   bool did_throw = false;
@@ -107,15 +100,13 @@ test_signal_bitfield::test_multiple() {
 void
 test_signal_bitfield::test_threaded() {
   std::atomic_uint32_t marked_bitfield{0};
-  test_thread* thread = new test_thread;
+
+  auto thread = test_thread::create();
   // thread->set_test_flag(test_thread::test_flag_long_timeout);
 
   for (unsigned int i = 0; i < torrent::signal_bitfield::max_size; i++)
     CPPUNIT_ASSERT(thread->signal_bitfield()->add_signal([i, &marked_bitfield] () { bitfield_mark_index(marked_bitfield, i); }) == i);
 
-// std::bind(&bitfield_mark_index, marked_bitfield, i)) == i);
-
-
   thread->init_thread();
   thread->start_thread();
 
@@ -132,10 +123,8 @@ test_signal_bitfield::test_threaded() {
     marked_bitfield &= ~uint32_t();
   }
 
-  thread->stop_thread();
-  CPPUNIT_ASSERT(wait_for_true(std::bind(&test_thread::is_state, thread, test_thread::STATE_INACTIVE)));
-
-  delete thread;
+  thread->stop_thread_wait();
+  CPPUNIT_ASSERT(wait_for_true(std::bind(&test_thread::is_state, thread.get(), test_thread::STATE_INACTIVE)));
 }
 
 // Test invalid signal added.
